@@ -64,4 +64,9 @@ class Browser:
         self.__conditions.DocumentReadyState().wait()
 
     def execute_javascript(self, js, *args):
-        return self.__automator.dispatcher.execute_javascript(js, *args)
\ No newline at end of file
+        return self.__automator.dispatcher.execute_javascript(js, *args)
+
+    def switch_to_dom_root(self):
+        self.__automator.dispatcher.switch_to_dom_root()
+
+    
\ No newline at end of file
