@@ -194,4 +194,17 @@ class GuiElement(AsserterMixIn, GuiWidgetContainer, Locatable, SingleGuiWidget):
             Returns:
                 `GuiRadioGroup` object
         '''
-        return self._finder.radio_group(fargs=fargs, **kwargs)
\ No newline at end of file
+        return self._finder.radio_group(fargs=fargs, **kwargs)
+
+    def frame(self, fargs=None, **kwargs):
+        '''
+            Locate a `GuiFrame`
+
+            Keyword Arguments:
+                fargs: A dictionary of key-value pairs for formatting the **GuiWidgetDefinition**. Use **.format(kwargs).wait_until_absent** for more Pythonic code when formatting.
+                **kwargs: Arbitrary key-value pairs used to construct a **GuiWidgetDefinition**
+
+            Returns:
+                `GuiFrame` object
+        '''
+        return self._finder.frame(fargs=fargs, **kwargs)
\ No newline at end of file
